# coding: utf-8

# flake8: noqa
"""
    EmployeeEFCrud

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from EFCrud.models.employee import Employee
from EFCrud.models.roles import Roles
from EFCrud.models.user import User
from EFCrud.models.user_roles import UserRoles
from EFCrud.models.userdto import Userdto
