# coding: utf-8

"""
    EmployeeEFCrud

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from EFCrud.api.features_api import FeaturesApi


class TestFeaturesApi(unittest.TestCase):
    """FeaturesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FeaturesApi()

    def tearDown(self) -> None:
        pass

    def test_api_features_id_delete(self) -> None:
        """Test case for api_features_id_delete

        """
        pass

    def test_api_features_id_put(self) -> None:
        """Test case for api_features_id_put

        """
        pass


if __name__ == '__main__':
    unittest.main()
